==> V00.90.zip: tweet_live-V00.90/web/edito-inaugurale/config.php <==
<?php
$config = array(
   	'hashtag'    => '#edito11',
   	'date'   => '03.11.2011',
   	'heure'   => '17h30-19h30',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Séance d'ouverture - les nouvelles écriture",
   	'abstract'   => "<b>Nouvelle forme d'éditorialisation</b>,<br/><b>Séance d'ouverture - les nouvelles écritures,</b><br/>le 03/11/2011 de 17h30 à 19h30<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "<i>Les nouvelles écritures et participation</i><br/>Pour beaucoup, le web est devenu la première – et parfois unique – source d’information, de connaissance et d’apprentissage. Mais comment ce savoir se construit-il ? Comment se structure-t-il ?
A l’heure où des risques de marchandisation extrême du Web et de fragmentation de la neutralité de l’Internet se font jours,  nous interrogerons les enjeux de cette constitution du savoir sur le web.",
   	'link' => '',
   	'islive'     => true,
   	'keywords'   => 'editorialisation, iri',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_edito.jpg',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-editorialisation.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-editorialisation.jpg', // 270 × 150 pixels

 	'archive_title' => "Séance d'ouverture - les nouvelles écriture",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou le jeudi 3 novembre 2011 17:30 - 19:30',

    // After the event
	'metadata'    => "http://www.iri.centrepompidou.fr/dev/ldt/ldtplatform/ldt/cljson/id/67280b1c-ff30-11e0-a82d-00145ea49a02",
	'duration'   => 23705500,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 740,
	'player_width'  => 650,
	'player_height' => 600,
);

==> V01.80.zip: tweet_live-V01.80/web/edito-inaugurale/config.php <==
<?php
$config = array(
   	'hashtag'    => '#edito11',
   	'date'   => '03.11.2011',
   	'heure'   => '17h30-19h30',
   	'place'   => 'Salle Triangle - Centre Pompidou',

   	'title' => "Séance d'ouverture - les nouvelles écritures",
   	'abstract'   => "<b>Nouvelle forme d'éditorialisation</b>,<br/><b>Séance d'ouverture - les nouvelles écritures,</b><br/>le 03/11/2011 de 17h30 à 19h30<br/>@ Salle Triangle (Centre Pompidou) - entrée libre et gratuite",
   	'description'=> "<i>Les nouvelles écritures et participation</i><br/>Pour beaucoup, le web est devenu la première – et parfois unique – source d’information, de connaissance et d’apprentissage. Mais comment ce savoir se construit-il ? Comment se structure-t-il ?
A l’heure où des risques de marchandisation extrême du Web et de fragmentation de la neutralité de l’Internet se font jours,  nous interrogerons les enjeux de cette constitution du savoir sur le web.",
   	'link' => 'http://seminaire.sens-public.org',
   	'islive'     => true,
   	'keywords'   => 'editorialisation, iri',
   	'rep' => basename(__DIR__),
   	'partenaires'=> "<a href='http://www.sens-public.org' class='footerLink' target='_blank'>Sens Public</a> | <a href='http://www.iri.centrepompidou.fr/' class='footerLink' target='_blank'>IRI</a>",

    'client_visual' => 'images/big_visuel_edito.jpg',// 501 × 376 pixels
    
 	'head_logo' => 'images/head_logo.gif', // 171 × 63 pixels
 	
  	'slide_background' => 'images/slide4-editorialisation.jpg', // 606 × 282 pixels
    
  	'archive_img' => 'images/archive-editorialisation.jpg', // 270 × 150 pixels

 	'archive_title' => "Séance d'ouverture - les nouvelles écriture",
 	'archive_description' => 'par <a href="http://www.sens-public.org" target="_blank">Sens Public</a> et l\'<a href="http://www.iri.centrepompidou.fr" target="_blank">IRI</a><br/>au Centre Pompidou le jeudi 3 novembre 2011 17:30 - 19:30',

    // After the event
	'metadata'    => "http://ldt.iri.centrepompidou.fr/ldtplatform/ldt/cljson/id/0911926e-093a-11e1-996f-00145ea49a02",
	'duration'   => 8357400,
	'player'        => "res/metadataplayer/src/js/LdtPlayer.js",
	'div_height'    => 700,
	'player_width'  => 650,
	'player_height' => 488,
);
